==> openpkg-registry-0.0.6.tar.gz: openpkg-registry-0.0.6/rpm.sh <==
#!@l_prefix@/lib/openpkg/bash
##
##  rpm -- OpenPKG Registry "rpm" overload command
##  Copyright (c) 2000-2005 OpenPKG Foundation e.V. <http://openpkg.net/>
##  Copyright (c) 2000-2005 Ralf S. Engelschall <http://engelschall.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   determine path to OpenPKG instance
PREFIX="@l_prefix@"
if [ ".${OPENPKG_PREFIX}" != . ]; then
    PREFIX="${OPENPKG_PREFIX}"
fi

#   determine old binary-only vs. shell+binary situation
oldbinnewsh="$PREFIX/libexec/openpkg/rpm" # old binary rpm, new embedded shell rpm
oldnanewbin="$PREFIX/lib/openpkg/rpm"     # old n/a, new binary rpm
if [ -x $oldbinnewsh -a -x $oldnanewbin ]; then exec $oldnanewbin "$@"; fi

##
##  read configuration unless already done during option parsing
##
readconf()
{
    [ ".$conf" = . ] && return
    if [ -r "$conf" ]; then
      # FIXME place a sanity and security file examination here
      . $conf
    fi
}

readutil()
{
    [ ".$REGISTRY_UTIL" = . ] && return
    if [ -r "$REGISTRY_UTIL" ]; then
      # FIXME place a sanity and security file examination here
      . $REGISTRY_UTIL
    fi
}


#   Configuration file default and read attempt
conf="$PREFIX/etc/openpkg/registry.conf"; readconf; readutil

#   main
if [ ".$REGISTRY_DONE" = .yes ]; then
    #   FIXME URL rewriting
    echo "openpkg:rpm:WARNING: this instance is registered. @=$@" >>/tmp/x 2>/dev/null || true
    $oldbinnewsh "$@"
else
    #   FIXME passthrough
    echo "openpkg:rpm:WARNING: this instance is not registered. Please run \"openpkg register\" @=$@" >>/tmp/x 2>/dev/null || true
    $oldbinnewsh "$@"
fi
exit 0

==> openpkg-registry-0.0.7.tar.gz: openpkg-registry-0.0.7/rpm.sh <==
#!@l_prefix@/lib/openpkg/bash
##
##  rpm -- OpenPKG Registry "rpm" overload command
##  Copyright (c) 2000-2005 OpenPKG Foundation e.V. <http://openpkg.net/>
##  Copyright (c) 2000-2005 Ralf S. Engelschall <http://engelschall.com/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   determine path to OpenPKG instance
PREFIX="@l_prefix@"
if [ ".${OPENPKG_PREFIX}" != . ]; then
    PREFIX="${OPENPKG_PREFIX}"
fi

#   determine old binary-only vs. shell+binary situation
oldbinnewsh="$PREFIX/libexec/openpkg/rpm" # old binary rpm, new embedded shell rpm
oldnanewbin="$PREFIX/lib/openpkg/rpm"     # old n/a, new binary rpm
if [ -x $oldbinnewsh -a -x $oldnanewbin ]; then exec $oldnanewbin "$@"; fi

##
##  read configuration unless already done during option parsing
##
readconf()
{
    [ ".$conf" = . ] && return
    if [ -r "$conf" ]; then
      # FIXME place a sanity and security file examination here
      . $conf
    fi
}

readuuid()

{
    [ ".$REGISTRY_UUID" = . ] && return
    if [ -r "$REGISTRY_UUID" ]; then
      # FIXME place a sanity and security file examination here
      . $REGISTRY_UUID
    fi
}

readutil()
{
    [ ".$REGISTRY_UTIL" = . ] && return
    if [ -r "$REGISTRY_UTIL" ]; then
      # FIXME place a sanity and security file examination here
      . $REGISTRY_UTIL
    fi
}


#   Configuration file default and read attempt
conf="$PREFIX/etc/openpkg/registry.conf"; readconf; readuuid; readutil

#   main
if [ ".$REGISTRY_DONE" = .yes ]; then
    echo "openpkg:rpm:WARNING: this instance is registered. @=$@" >>/tmp/x 2>/dev/null || true #FIXME DEBUG
    #   URL rewriting
    declare -a a
    declare -i i=0
    while [ ".$1" != . ]; do
        arg="$1"
        arg=`echo $arg | sed -e "s;^\(ftp\|http\)://\(ftp.openpkg.\(com\|org\|net\)\)\(/[^@/]*/.*\)$;\1://$UUID_REGISTRY:$UUID_INSTANCE-$UUID_PLATFORM@\\2\\4;"`
        a[$i]="$arg"
        i=i+1
        shift
    done
    set -- "${a[@]}"
    unset arg i a
    echo "openpkg:rpm:WARNING: this instance was rewritten. @=$@" >>/tmp/x 2>/dev/null || true #FIXME DEBUG
    $oldbinnewsh "$@"
else
    #   stealth mode
    echo "openpkg:rpm:WARNING: this instance is not registered. Please run \"openpkg register\" @=$@" >>/tmp/x 2>/dev/null || true #FIXME DEBUG
fi
exec $oldbinnewsh "$@"
